@@ -137,13 +137,18 @@ class GdbmCache(LdapCache):
 				except KeyError:
 					pass
 
-	def __iter__(self):
+	def keys(self):
 		with self.reading() as reader:
 			key = _s(reader.firstkey())
 			while key is not None:
-				yield key, self.get(key, reader)
+				yield key
 				key = _s(reader.nextkey(key))
 
+	def __iter__(self):
+		with self.reading() as reader:
+			for key in self.keys():
+				yield key, self.get(key, reader)
+
 	def get(self, key, reader=None):
 		with self.reading(reader) as reader:
 			try:
@@ -159,7 +164,7 @@ class GdbmCache(LdapCache):
 
 	def load(self):
 		debug('%s - Loading', self.name)
-		return dict(self)
+		return dict(list(self))
 
 
 class GdbmShard(Shard):
